(gc)A set of GC metric collectors for the JVM.
Can be attached to a iapetos registry using iapetos.core/register.
A set of GC metric collectors for the JVM. Can be attached to a iapetos registry using `iapetos.core/register`.
(initialize registry)Attach all available JVM collectors to the given registry.
Attach all available JVM collectors to the given registry.
(memory-pools)A set of memory usage metric collectors for the JVM.
Can be attached to a iapetos registry using iapetos.core/register.
A set of memory usage metric collectors for the JVM. Can be attached to a iapetos registry using `iapetos.core/register`.
(standard)A set of standard collectors for the JVM.
Can be attached to a iapetos registry using iapetos.core/register.
A set of standard collectors for the JVM. Can be attached to a iapetos registry using `iapetos.core/register`.
(threads)A set of thread usage metric collectors for the JVM.
Can be attached to a iapetos registry using iapetos.core/register.
A set of thread usage metric collectors for the JVM. Can be attached to a iapetos registry using `iapetos.core/register`.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |